/*
 * Copyright (C) 2007 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#if !defined HATP_PARSER_EXCEPTION_HH_
#define HATP_PARSER_EXCEPTION_HH_

#include<string>
#include<sstream>

#define ERROR 1
#define WARNING 2

/** Class of exception thrown when an error occurs while parsing the domain file
*/
class HATPParserException
{
private:
	/** Text of the exception */
	std::string txt;

	/** Define the type of the exception (ERROR or WARNING) */
	unsigned int type;

	/** Line number in the domain file linked to the exception */
	unsigned int line;

public:
	/** Constructor : sets s to txt and i to type
	* @param type Type of exception
	* @param argLine Line where the exception is in the domain file
	* @param text Error message
	*/
	explicit HATPParserException(unsigned int type, size_t argLine, std::string text):txt(text), type(type), line(argLine) {}

	/** Returns the type of exception
	* @return The exception's type
	*/
	unsigned int getType()
	{
		return type;
	}

	/** Returns the line where the exception occured in the domain file
	* @return The line number
	*/
	size_t getLineNumber()
	{
		return line;
	}

	/** Returns the exception message
	* @return Exception message
	*/
	std::string getMessage(){
		return txt;
	}
};

#endif
