#include<iostream>
#include<sstream>

#include "BeliefMethod.hh"

using namespace std;

/** Add a task to handle a type of divergent belief.
 * @param type The type of the task. (See BeliefMethod::Type)
 * @param task The task to add.
 */
void BeliefMethod::addCommTask(Type type, Task* task) {
	this->commTasks[type] = task;
}

/** Get the task that handles a certain type of belief.
 * @param type The type of the task. (See BeliefMethod::Type)
 * @return The task found, NULL otherwise.
 */
Task* BeliefMethod::getTaskOfType(Type type) {
	if(this->commTasks.find(type) == this->commTasks.end()) {
		cerr << "ERROR: Communication Task not found for: " << type << endl;
		return NULL;
	}
	return this->commTasks.find(type)->second;
}

/** Create a string to represent the belief methods.
 * @return A string representing all the belief methods.
 */
string BeliefMethod::toString() {
	ostringstream st;
	st << "========== BELIEF MANAGEMENT ==========\n";
	for(map<Type, Task*>::iterator it = this->commTasks.begin(); it != this->commTasks.end(); it++) {
		st << typeToString(it->first) <<": " << it->second->toString() << "\n";
	}
	st << "=======================================\n";
	return st.str();
}

/** Get the string corresponding to a give BeliefMethod::Type.
 * @param type Type to cast
 * @return A string to represent the type
 */
string BeliefMethod::typeToString(Type type){
	switch(type){
		case information: return "information";
			break;
		case contradiction: return "contradiction";
			break;
		case question: return "question";
			break;
	}
	return "unknown";
}
