# Find the Antlr module
# Once found the following variables are set :
#	Antlr_FOUND		True to specify that the module has been found
#
#	Antlr_INCLUDE_DIRS	Path(s) to the headers
#
#	Antlr_LIBRARIES		Link these to use Antlr
#
#	Antlr_EXECUTABLE	Path to the antlr binary

# To help CMake in finding the Antlr module
# one can set the following variables :
# Antlr_INCLUDE To give the path to the folder containing the header files
# or
# AntlrINCLUDE
#
# Antlr_LIB To give the path to (or the containing forlder of) the library file of Antlr
# or
# AntlrLIB
#
# Antlr_BIN To give the full path to (or the containing forlder of) the Antlr binary
# or
# AntlrBIN
#
# You can set any of them using one of the following methods :
#	1) Set it as environnement varialbe (e.g. export, setenv, ...)
#	2) Give it as argument for cmake : cmake -D<var>="...."
#	3) In a CMakeLists.txt, set a variable : set(<var> ...)	

#Varaibles to change if the module changes
set(HEADERS antlr/ANTLRException.hpp antlr/ANTLRUtil.hpp antlr/AST.hpp antlr/ASTArray.hpp antlr/ASTFactory.hpp antlr/ASTNULLType.hpp antlr/ASTPair.hpp antlr/ASTRefCount.hpp antlr/BaseAST.hpp antlr/BitSet.hpp antlr/CharBuffer.hpp antlr/CharInputBuffer.hpp antlr/CharScanner.hpp antlr/CharStreamException.hpp antlr/CharStreamIOException.hpp antlr/CircularQueue.hpp antlr/CommonAST.hpp antlr/CommonASTWithHiddenTokens.hpp antlr/CommonHiddenStreamToken.hpp antlr/CommonToken.hpp antlr/IOException.hpp antlr/InputBuffer.hpp antlr/LLkParser.hpp antlr/LexerSharedInputState.hpp antlr/MismatchedCharException.hpp antlr/MismatchedTokenException.hpp antlr/NoViableAltException.hpp antlr/NoViableAltForCharException.hpp antlr/Parser.hpp antlr/ParserSharedInputState.hpp antlr/RecognitionException.hpp antlr/RefCount.hpp antlr/SemanticException.hpp antlr/String.hpp antlr/Token.hpp antlr/TokenBuffer.hpp antlr/TokenRefCount.hpp antlr/TokenStream.hpp antlr/TokenStreamBasicFilter.hpp antlr/TokenStreamException.hpp antlr/TokenStreamHiddenTokenFilter.hpp antlr/TokenStreamIOException.hpp antlr/TokenStreamRecognitionException.hpp antlr/TokenStreamRetryException.hpp antlr/TokenStreamRewriteEngine.hpp antlr/TokenStreamSelector.hpp antlr/TokenWithIndex.hpp antlr/TreeParser.hpp antlr/TreeParserSharedInputState.hpp antlr/config.hpp)
set(LIBRARIES libantlr.a)
set(EXECUTABLE runantlr antlr runantlr2)

unset(Antlr_INCLUDE_DIRS)
foreach(header ${HEADERS})
	find_path(${header}_PATH ${header} PATH_SUFFIXES include
		HINTS ${Antlr_INCLUDE} ${AntlrINCLUDE}
		$ENV{antlr_INCLUDE} $ENV{AntlrINCLUDE}
		${Antlr_DIR} ${Antlr_ROOT} ${AntlrROOT}
		$ENV{Antlr_DIR} $ENV{Antlr_ROOT} $ENV{AntlrROOT})
	if(${header}_PATH)
		list(APPEND Antlr_INCLUDE_DIRS ${${header}_PATH})
	else(${header}_PATH)
		list(APPEND MISSING_HEADERS ${header})
	endif(${header}_PATH)
endforeach()

if(Antlr_INCLUDE_DIRS)
	list(REMOVE_DUPLICATES Antlr_INCLUDE_DIRS)
endif(Antlr_INCLUDE_DIRS)

if(MISSING_HEADERS)
	unset(Antlr_INCLUDE_DIRS)
endif(MISSING_HEADERS)

unset(Antlr_LIBRARIES)
find_file(Antlr_LIBRARIES ${LIBRARIES} PATH_SUFFIXES lib
	HINTS ${Antlr_LIB} ${AntlrLIB} ${AntlrLIBDIR}
	$ENV{Antlr_LIB} $ENV{AntlrLIB} $ENV{AntlrLIBDIR}
	${Antlr_DIR} ${Antlr_ROOT} ${AntlrROOT}
	$ENV{Antlr_DIR} $ENV{Antlr_ROOT} $ENV{AntlrROOT})
if(NOT Antlr_LIBRARIES)
	if(DEFINED Antlr_LIB)
		if(${Antlr_LIB} MATCHES "(.*)/libantlr.a")
			find_file(Antlr_LIBRARIES ${LIBRARIES} PATH_SUFFIXES lib
				HINTS ${CMAKE_MATCH_1})
		endif(${Antlr_LIB} MATCHES "(.*)/libantlr.a")
	elseif(DEFINED AntlrLIB)
		if(${AntlrLIB} MATCHES "(.*)/libantlr.a")
			find_file(Antlr_LIBRARIES ${LIBRARIES} PATH_SUFFIXES lib
				HINTS ${CMAKE_MATCH_1})
		endif(${AntlrLIB} MATCHES "(.*)/libantlr.a")
	elseif(NOT $ENV{Antlr_LIB} STREQUAL "")
		if($ENV{Antlr_LIB} MATCHES "(.*)/libantlr.a")
			find_file(Antlr_LIBRARIES ${LIBRARIES} PATH_SUFFIXES lib
				HINTS ${CMAKE_MATCH_1})
		endif($ENV{Antlr_LIB} MATCHES "(.*)/libantlr.a")
	elseif(NOT $ENV{AntlrLIB} STREQUAL "")
		if($ENV{AntlrLIB} MATCHES "(.*)/libantlr.a")
			find_file(Antlr_LIBRARIES ${LIBRARIES} PATH_SUFFIXES lib
				HINTS ${CMAKE_MATCH_1})
		endif($ENV{AntlrLIB} MATCHES "(.*)/libantlr.a")
	endif(DEFINED Antlr_LIB)
endif(NOT Antlr_LIBRARIES)




unset(Antlr_EXECUTABLE)
if(DEFINED Antlr_BIN OR DEFINED AntlrBIN
OR NOT $ENV{Antlr_BIN} STREQUAL "" OR NOT $ENV{AntlrBIN} STREQUAL ""
OR DEFINED Antlr_DIR OR DEFINED Antlr_ROOT OR DEFINED AntlrROOT
OR NOT $ENV{Antlr_DIR} STREQUAL "" OR NOT $ENV{Antlr_ROOT} STREQUAL "" OR NOT $ENV{AntlrROOT} STREQUAL "")
	find_program(Antlr_EXECUTABLE NAMES ${EXECUTABLE} PATH_SUFFIXES bin
		HINTS ${Antlr_BIN} ${AntlrBIN}
		$ENV{Antlr_BIN} $ENV{AntlrBIN}
		${Antlr_DIR} ${Antlr_ROOT} ${AntlrROOT}
		$ENV{Antlr_DIR} $ENV{Antlr_ROOT} $ENV{AntlrROOT}
		NO_DEFAULT_PATH)
else(DEFINED Antlr_BIN OR DEFINED AntlrBIN
OR NOT $ENV{Antlr_BIN} STREQUAL "" OR NOT $ENV{AntlrBIN} STREQUAL ""
OR DEFINED Antlr_DIR OR DEFINED Antlr_ROOT OR DEFINED AntlrROOT
OR NOT $ENV{Antlr_DIR} STREQUAL "" OR NOT $ENV{Antlr_ROOT} STREQUAL "" OR NOT $ENV{AntlrROOT} STREQUAL "")
	find_program(Antlr_EXECUTABLE NAMES ${EXECUTABLE})
endif(DEFINED Antlr_BIN OR DEFINED AntlrBIN
OR NOT $ENV{Antlr_BIN} STREQUAL "" OR NOT $ENV{AntlrBIN} STREQUAL ""
OR DEFINED Antlr_DIR OR DEFINED Antlr_ROOT OR DEFINED AntlrROOT
OR NOT $ENV{Antlr_DIR} STREQUAL "" OR NOT $ENV{Antlr_ROOT} STREQUAL "" OR NOT $ENV{AntlrROOT} STREQUAL "")

if(NOT Antlr_EXECUTABLE)
	if(DEFINED Antlr_BIN)
		if(${Antlr_BIN} MATCHES "(.*)/(run)?antlr")
			find_program(Antlr_EXECUTABLE NAMES ${EXECUTABLE} PATH_SUFFIXES bin
				HINTS ${CMAKE_MATCH_1}
				NO_DEFAULT_PATH)
		endif(${Antlr_BIN} MATCHES "(.*)/(run)?antlr")
	elseif(DEFINED AntlrBIN)
		if(${Antlr_BIN} MATCHES "(.*)/(run)?antlr")
			find_program(Antlr_EXECUTABLE NAMES ${EXECUTABLE} PATH_SUFFIXES bin
				HINTS ${CMAKE_MATCH_1}
				NO_DEFAULT_PATH)
		endif(${Antlr_BIN} MATCHES "(.*)/(run)?antlr")
	elseif(NOT $ENV{Antlr_BIN} STREQUAL "")
		if($ENV{Antlr_BIN} MATCHES "(.*)/(run)?antlr")
			find_program(Antlr_EXECUTABLE NAMES ${EXECUTABLE} PATH_SUFFIXES bin
				HINTS ${CMAKE_MATCH_1}
				NO_DEFAULT_PATH)
		endif($ENV{Antlr_BIN} MATCHES "(.*)/(run)?antlr")
	elseif(NOT $ENV{Antlr_BIN} STREQUAL "")
		if($ENV{AntlrBIN} MATCHES "(.*)/(run)?antlr")
			find_program(Antlr_EXECUTABLE NAMES ${EXECUTABLE} PATH_SUFFIXES bin
				HINTS ${CMAKE_MATCH_1}
				NO_DEFAULT_PATH)
		endif($ENV{AntlrBIN} MATCHES "(.*)/(run)?antlr")
	endif(DEFINED Antlr_BIN)
endif(NOT Antlr_EXECUTABLE)




if(Antlr_INCLUDE_DIRS AND Antlr_LIBRARIES AND Antlr_EXECUTABLE)
	set(Antlr_FOUND TRUE)
else(Antlr_INCLUDE_DIRS AND Antlr_LIBRARIES AND Antlr_EXECUTABLE)
	if(NOT Antlr_FIND_QUIETLY)
		if(NOT Antlr_INCLUDE_DIRS)
			message(STATUS "Unable to find Antlr header files!")
		else(NOT Antlr_INCLUDE_DIRS)
			message(STATUS "Header files found.")
		endif(NOT Antlr_INCLUDE_DIRS)
		if(NOT Antlr_LIBRARIES)
			message(STATUS "Unable to find Antlr library files!")
		else(NOT Antlr_LIBRARIES)
			message(STATUS "Library files found.")
		endif(NOT Antlr_LIBRARIES)
		if(NOT Antlr_EXECUTABLE)
			message(STATUS "Unable to find Antlr executable!")
		else(NOT Antlr_EXECUTABLE)
			message(STATUS "Antlr executable found.")
		endif(NOT Antlr_EXECUTABLE)
	endif(NOT Antlr_FIND_QUIETLY)
endif(Antlr_INCLUDE_DIRS AND Antlr_LIBRARIES AND Antlr_EXECUTABLE)

if(Antlr_FOUND)
	if(NOT Antlr_FIND_QUIETLY)
		message(STATUS "Found components for Antlr")
		message(STATUS "Antlr_INCLUDE_DIRS = ${Antlr_INCLUDE_DIRS}")
		message(STATUS "Antlr_LIBRARIES = ${Antlr_LIBRARIES}")
		message(STATUS "Antlr_EXECUTABLE = ${Antlr_EXECUTABLE}")
	endif(NOT Antlr_FIND_QUIETLY)
else(Antlr_FOUND)
	if(Antlr_FIND_REQUIRED)
		set(Antlr_DIR "" CACHE PATH "Path to Antlr")
		set(Antlr_ROOT "" CACHE PATH "Path to Antlr")
		set(AntlrROOT "" CACHE PATH "Path to Antlr")
		set(Antlr_INCLUDE "" CACHE PATH "Path where to additionally look for Antlr headers")
		set(AntlrINCLUDE "" CACHE PATH "Path where to additionally look for Antlr headers")
		set(Antlr_LIB "" CACHE PATH "Path where to additionally look for Antlr library")
		set(AntlrLIB "" CACHE PATH "Path where to additionally look for Antlr library")
		set(Antlr_BIN "" CACHE PATH "Path where to additionally look for to Antlr binary")
		set(AntlrBIN "" CACHE PATH "Path where to additionally look for to Antlr binary")
		if(NOT Antlr_FIND_QUIETLY)
			message("\nCould not find Antlr!\n")
			message("You can use any of the following varaibles to help CMake to find Antlr (both headers, libraries and executale):")
			message("	Antlr_DIR Antlr_ROOT or AntlrROOT")
			message("You can use any of the following variables to help CMake to find the header files :")
			message("	Antlr_INCLUDE or AntlrINCLUDE")
			message("You can use any of the following variables to help CMake to find the library (can be the path or the file):")
			message("	Antlr_LIB or AntlrLIB")
			message("You can use any of the following varaible to give the Antlr binary file (can be the path or the binary file):")
			message("	Antlr_BIN or AntlrBIN")
			message("To set one you can either :")
			message("	- use 'set(<var> ....)' command in the CMakeLists.txt (separator ' ')")
			message("	- use '-D<var>=....' as an option to Cmake (separator ';')")
			message("	- set one as an environment variable (e.g. export in bash, with separator ';')\n")
		endif(NOT Antlr_FIND_QUIETLY)
		message(FATAL_ERROR "Could not find Antlr!")
	endif(Antlr_FIND_REQUIRED)
endif(Antlr_FOUND)

mark_as_advanced (
	Antlr_FOUND
	Antlr_INCLUDE_DIRS
	Antlr_LIBRARIES
	Antlr_EXECUTABLE
)
